==> avaje-inject-generator-10.4-sources.jar: io/avaje/inject/generator/package-info.java <==
@GeneratePrism(AOPFallback.class)
@GeneratePrism(Aspect.class)
@GeneratePrism(value = Aspect.Import.class, name = "AspectImportPrism")
@GeneratePrism(Assisted.class)
@GeneratePrism(AssistFactory.class)
@GeneratePrism(Bean.class)
@GeneratePrism(Component.class)
@GeneratePrism(Component.Import.class)
@GeneratePrism(DependencyMeta.class)
@GeneratePrism(External.class)
@GeneratePrism(Factory.class)
@GeneratePrism(Generated.class)
@GeneratePrism(Inject.class)
@GeneratePrism(InjectModule.class)
@GeneratePrism(BeanTypes.class)
@GeneratePrism(Lazy.class)
@GeneratePrism(Named.class)
@GeneratePrism(PreDestroy.class)
@GeneratePrism(Primary.class)
@GeneratePrism(Profile.class)
@GeneratePrism(Prototype.class)
@GeneratePrism(Proxy.class)
@GeneratePrism(QualifiedMap.class)
@GeneratePrism(Qualifier.class)
@GeneratePrism(RequiresBean.class)
@GeneratePrism(RequiresProperty.class)
@GeneratePrism(value = RequiresBean.Container.class, name = "RequiresBeanContainerPrism")
@GeneratePrism(value = RequiresProperty.Container.class, name = "RequiresPropertyContainerPrism")
@GeneratePrism(Singleton.class)
@GeneratePrism(Scope.class)
@GeneratePrism(Secondary.class)
package io.avaje.inject.generator;

import io.avaje.inject.*;
import io.avaje.inject.aop.Aspect;
import io.avaje.inject.aop.AOPFallback;
import io.avaje.inject.spi.*;
import io.avaje.prism.GeneratePrism;
import jakarta.inject.Inject;
import jakarta.inject.Named;
import jakarta.inject.Qualifier;
import jakarta.inject.Scope;
import jakarta.inject.Singleton;

==> avaje-inject-generator-11.2-sources.jar: io/avaje/inject/generator/package-info.java <==
@GeneratePrism(AOPFallback.class)
@GeneratePrism(Aspect.class)
@GeneratePrism(value = Aspect.Import.class, name = "AspectImportPrism")
@GeneratePrism(Assisted.class)
@GeneratePrism(AssistFactory.class)
@GeneratePrism(Bean.class)
@GeneratePrism(Component.class)
@GeneratePrism(Component.Import.class)
@GeneratePrism(DependencyMeta.class)
@GeneratePrism(External.class)
@GeneratePrism(Factory.class)
@GeneratePrism(Generated.class)
@GeneratePrism(Inject.class)
@GeneratePrism(InjectModule.class)
@GeneratePrism(BeanTypes.class)
@GeneratePrism(Lazy.class)
@GeneratePrism(Named.class)
@GeneratePrism(PluginProvides.class)
@GeneratePrism(PreDestroy.class)
@GeneratePrism(Primary.class)
@GeneratePrism(Profile.class)
@GeneratePrism(Prototype.class)
@GeneratePrism(Proxy.class)
@GeneratePrism(QualifiedMap.class)
@GeneratePrism(Qualifier.class)
@GeneratePrism(RequiresBean.class)
@GeneratePrism(RequiresProperty.class)
@GeneratePrism(value = RequiresBean.Container.class, name = "RequiresBeanContainerPrism")
@GeneratePrism(value = RequiresProperty.Container.class, name = "RequiresPropertyContainerPrism")
@GeneratePrism(Singleton.class)
@GeneratePrism(Scope.class)
@GeneratePrism(Secondary.class)
@GeneratePrism(io.avaje.spi.ServiceProvider.class)
@GeneratePrism(io.avaje.http.api.Client.class)
@GeneratePrism(io.avaje.http.api.Controller.class)
@GeneratePrism(io.avaje.http.api.Path.class)
@GeneratePrism(name = "HttpGeneratedPrism", value = io.avaje.http.api.Generated.class)
package io.avaje.inject.generator;

import io.avaje.inject.*;
import io.avaje.inject.aop.Aspect;
import io.avaje.inject.aop.AOPFallback;
import io.avaje.inject.spi.*;
import io.avaje.prism.GeneratePrism;
import jakarta.inject.Inject;
import jakarta.inject.Named;
import jakarta.inject.Qualifier;
import jakarta.inject.Scope;
import jakarta.inject.Singleton;
